@@ -43,10 +43,8 @@ class ExecMode(object):
         if code is None:
             code = 'case'
 
-        root_dir = os.path.dirname(os.path.dirname(__file__))
-
-        user_dir = func.makeDir(root_dir, 'testcase', work_mode.value.lower(), self._username)
-        template_file = os.path.join(root_dir, 'template', 'testcase_v1.tmp')
+        user_dir = func.makeDir(os.environ.get('PROJECT_DIR'), 'testcase', work_mode.value.lower(), self._username)
+        template_file = os.path.join(os.path.dirname(os.path.dirname(__file__)), 'template', 'testcase_v1.tmp')
         script_file = os.path.join(user_dir, 'test_{}.py'.format(code))
 
         with open(template_file, 'r', encoding='UTF-8') as file:
